#!/bin/sh
# This script is use to build the Sangoma TDM SDK

# We should not deliver the Decoder code which is Trillium specific, hence building decoder module from here
# and only including sng_decoder library to the release Sangoma TDM SDK.

echo
echo "Please run 'make distclean' before making the release!"  
echo "Proceed ? Y/N"
read var

if [ "$var" != "Y" ] && [ "$var" != "y" ]; then
	exit 1
fi

if [ ! -e libs/decoders/sng_decoder ]; then
	echo "Error: sng_decoder not found!"
	exit 1
fi

DECODER_PUBLIC_H="cm/sng_decoder.h cm/envdep.h"

DECODER_LINUX=libs/decoders/sng_decoder/src/libsng_decoder.so* 
DECODER_WIN=libs/decoders/sng_decoder/Win_VS2010/src/Debug/libsng_decode*
VER=${1:-1.0.9}
DIR="sangoma-tdm-sdk-v$VER"

if [ -e ../$DIR ]; then
	rm -rf ../$DIR
	rm -f ../$DIR.zip
fi

HOME=$(pwd)

function tagit
{
    cd $HOME
    home=$(pwd);
    gitdirs="libs/decoders/sng_decoder"

    if [ -z $VER ]; then
        echo "Error: Invalid version specified ($VER)"
        return 1
    fi

    #Tag the container
    cmd="git tag -m 'Tag $VER' -a '$VER'"
    echo "$cmd"
    eval "$cmd"
    git push origin $VER

 #Tag all other dirs
    for dir in $gitdirs
    do
        cd $home/$dir
        if [ $? -ne 0 ]; then
            echo "Error: Faild to change dir $home/$dir"
            continue
        fi

        cmd="git tag -m 'Tag $VER' -a '$VER'"
        echo "$cmd"
        eval "$cmd"
        git push origin $VER
    done

    cd $HOME
}

cd libs/decoders/sng_decoder
cmake .  > /dev/null 2>&1
make     > /dev/null 2>&1

if [ ! -e  src/libsng_decoder.so ]; then
	echo "Error: Faile to build sng_decode"
	echo
	exit 1
fi

cd $HOME

# Make release tar ball
mkdir ../$DIR
tar cf - --exclude=mkrelease.sh  . | (cd ../$DIR && tar xBf -) 
rm -rf ../$DIR/libs/decoders/sng_decoder
tar cf - $DECODER_LINUX | (cd ../$DIR && tar xBf -)
tar cf - $DECODER_WIN  | (cd ../$DIR && tar xBf -)
cd libs/decoders/sng_decoder
tar cf - $(echo $DECODER_PUBLIC_H | xargs) | (cd $HOME/../$DIR/libs/decoders/sng_decoder/ && tar xBf -)
tar cf - Makefile | (cd $HOME/../$DIR/libs/decoders/sng_decoder/ && tar xBf -)
cd $HOME

if [ "$2" = "release" ]; then
    tagit
fi

cd ../
zip -r $DIR.zip $DIR
